@@ -152,9 +152,9 @@ gb_combo_get_properties (GtkWidget * widget, GbWidgetGetArgData * data)
 static void
 add_label (GtkWidget * widget, GString *items)
 {
-  gchar *label_text;
+  const gchar *label_text;
 
-  gtk_label_get (GTK_LABEL (GTK_BIN (widget)->child), &label_text);
+  label_text = gtk_label_get_text (GTK_LABEL (GTK_BIN (widget)->child));
   g_string_append (items, label_text);
   g_string_append_c (items, '\n');
 }
@@ -247,6 +247,9 @@ gb_combo_set_properties (GtkWidget * widget, GbWidgetSetArgData * data)
 	      gtk_widget_show (listitem);
 	      gtk_container_add (GTK_CONTAINER (list), listitem);
 
+	      if (item_end != items_end)
+		*item_end = '\n';
+
 	      pos = item_end + 1;
 	    }
 
@@ -291,8 +294,8 @@ gb_combo_write_source (GtkWidget * widget, GbWidgetWriteSourceData * data)
   /* We store a pointer to the popup window's parent combo, so lookup_widget()
      will still work when the popup window is passed as the first arg. */
   source_add (data,
-	      "  gtk_object_set_data (GTK_OBJECT (GTK_COMBO (%s)->popwin),\n"
-	      "                       \"GladeParentKey\", %s);\n",
+	      "  g_object_set_data (G_OBJECT (GTK_COMBO (%s)->popwin),\n"
+	      "                     \"GladeParentKey\", %s);\n",
 	      data->wname, data->wname);
 
   gb_widget_write_standard_source (widget, data);
@@ -366,8 +369,8 @@ gb_combo_write_source (GtkWidget * widget, GbWidgetWriteSourceData * data)
 static void
 write_items_source_callback (GtkWidget * item, GbWidgetWriteSourceData * data)
 {
-  gchar *label_text;
-  gtk_label_get (GTK_LABEL (GTK_BIN (item)->child), &label_text);
+  const gchar *label_text;
+  label_text = gtk_label_get_text (GTK_LABEL (GTK_BIN (item)->child));
   /* The (gpointer) cast is just to keep g++ happy. */
   source_add (data, "  %s_items = g_list_append (%s_items, (gpointer) %s);\n",
 	      data->real_wname, data->real_wname,
