@@ -133,7 +133,7 @@ gb_label_create_standard_properties (GtkWidget * widget,
 
   property_add_text (label_p, _("Label:"), _("The text to display"), 5);
   property_add_bool (use_underline_p, _("Use Underline:"),
-		     _("If the text includes an underlined accelerator character"));
+		     _("If the text includes an underlined access key"));
   property_add_bool (use_markup_p, _("Use Markup:"),
 		     _("If the text includes pango markup"));
   property_add_choice (justify_p, _("Justify:"),
@@ -154,11 +154,11 @@ gb_label_create_standard_properties (GtkWidget * widget,
   property_add_int_range (ypad_p, _("Y Pad:"), _("The vertical padding"),
 			  0, 1000, 1, 10, 1);
   property_add_combo (focus_target_p, _("Focus Target:"),
-		      _("The widget to set the keyboard focus to when the underlined accelerator key is used"),
+		      _("The widget to set the keyboard focus to when the underlined access key is used"),
 		      NULL);
   combo = property_get_value_widget (focus_target_p);
   gtk_editable_set_editable (GTK_EDITABLE (GTK_COMBO (combo)->entry), FALSE);
-  gtk_combo_set_value_in_list (GTK_COMBO (combo), TRUE, TRUE);
+  /*gtk_combo_set_value_in_list (GTK_COMBO (combo), TRUE, TRUE);*/
 }
 
 
@@ -350,7 +350,7 @@ gb_label_get_focus_targets (GtkWidget * widget,
     {
       *focus_targets = g_list_insert_sorted (*focus_targets,
 					     (gchar*) gtk_widget_get_name (widget),
-					     g_str_equal);
+					     (GCompareFunc) g_utf8_collate);
     }
 
   if (GTK_IS_CONTAINER (widget))
@@ -611,7 +611,7 @@ gb_label_write_standard_source (GtkWidget * widget,
 	}
     }
 
-  if (GTK_LABEL (widget)->jtype != GTK_JUSTIFY_CENTER)
+  if (GTK_LABEL (widget)->jtype != GTK_JUSTIFY_LEFT)
     {
       for (i = 0; i < sizeof (GbJustifyValues) / sizeof (GbJustifyValues[0]);
 	   i++)
