@@ -57,6 +57,9 @@ static gchar *Shrink = "GtkWindow::allow_shrink";
 static gchar *Grow = "GtkWindow::allow_grow";
 
 
+/* The key to hold the icon filename. */
+static gchar *GladeWindowIconKey = "GladeWindowIconKey";
+
 static const gchar *GbTypeChoices[] =
 {"Top Level", "Popup", NULL};
 static const gint GbTypeValues[] =
@@ -406,7 +409,7 @@ gb_window_get_standard_properties (GtkWidget * widget,
   if (icon_p)
     gb_widget_output_pixmap_filename (data, icon_p,
 				      gtk_object_get_data (GTK_OBJECT (widget),
-							   icon_p));
+							   GladeWindowIconKey));
 }
 
 
@@ -616,10 +619,10 @@ gb_window_set_standard_properties (GtkWidget * widget,
 	    filename = NULL;
 
 	  /* Remove the old pixmap from the project. */
-	  old_filename = gtk_object_get_data (GTK_OBJECT (widget), icon_p);
+	  old_filename = gtk_object_get_data (GTK_OBJECT (widget), GladeWindowIconKey);
 	  glade_project_remove_pixmap (data->project, old_filename);
 
-	  gtk_object_set_data_full (GTK_OBJECT (widget), icon_p,
+	  gtk_object_set_data_full (GTK_OBJECT (widget), GladeWindowIconKey,
 				    g_strdup (filename),
 				    filename ? g_free : NULL);
 
@@ -817,7 +820,7 @@ gb_window_write_standard_source (GtkWidget * widget,
 
   if (icon_p)
     {
-      gchar *filename = gtk_object_get_data (GTK_OBJECT (widget), icon_p);
+      gchar *filename = gtk_object_get_data (GTK_OBJECT (widget), GladeWindowIconKey);
       if (filename && *filename)
 	{
 	  char *pixbuf_name = g_strdup_printf ("%s_icon_pixbuf", data->wname);
@@ -840,6 +843,17 @@ gb_window_write_standard_source (GtkWidget * widget,
 }
 
 
+void
+gb_window_destroy (GtkWidget * widget, GbWidgetDestroyData * data)
+{
+  gchar *filename;
+
+  /* glade_project_remove_pixmap() will just ignore it if it is NULL. */
+  filename = gtk_object_get_data (GTK_OBJECT (widget), GladeWindowIconKey);
+  glade_project_remove_pixmap (data->project, filename);
+}
+
+
 /*
  * Initializes the GbWidget structure.
  * I've placed this at the end of the file so we don't have to include
@@ -865,6 +879,7 @@ gb_window_init ()
   gbwidget.gb_widget_get_properties = gb_window_get_properties;
   gbwidget.gb_widget_set_properties = gb_window_set_properties;
   gbwidget.gb_widget_write_source = gb_window_write_source;
+  gbwidget.gb_widget_destroy = gb_window_destroy;
 /*
    gbwidget.gb_widget_create_popup_menu = gb_window_create_popup_menu;
  */
