@@ -23,6 +23,8 @@
 #endif
 #include <errno.h>
 
+#include <dirent.h>
+
 #include <libxml/parser.h>
 
 #include <gtk/gtkmenu.h>
@@ -46,7 +48,7 @@ GladeProject *current_project = NULL;
 /* The order must match the GladeLanguageType enum in glade_project.h. */
 gchar *GladeLanguages[] = { "C", "C++" , "Ada 95", "Perl", "Eiffel" };
 #if 1
-gint GladeNumLanguages = 2; /* Only C and C++ for now. */
+gint GladeNumLanguages = 3; /* Only C, C++ and Ada ported to GTK+ 2. */
 #else
 gint GladeNumLanguages = sizeof (GladeLanguages) / sizeof (GladeLanguages[0]);
 #endif
@@ -251,8 +253,6 @@ glade_project_destroy (GtkObject *object)
   g_free (project->pixmaps_directory);
   project->pixmaps_directory = NULL;
 
-  tree_clear ();
-
   /* Destroy all project components. */
   tmp_list = project->components;
   while (tmp_list)
@@ -263,6 +263,11 @@ glade_project_destroy (GtkObject *object)
   g_list_free (project->components);
   project->components = NULL;
 
+  /* Empty the tree. Do this after the widgets are destroyed as it is a bit
+     safer since the widgets won't ever have invalid pointers to the tree
+     nodes. */
+  tree_clear ();
+
   /* Destroy the unique id hash. */
   if (project->unique_id_hash)
     {
@@ -528,7 +533,11 @@ glade_project_write_ada95_source (GladeProject *project)
 {
   gchar *command_buffer;
   gint status;
- 
+
+#ifdef _WIN32
+  chdir(project->directory);
+#endif
+  
   command_buffer = g_strdup_printf ("gate %s", project->xml_filename);
   status = system (command_buffer);
   g_free (command_buffer);
@@ -1586,10 +1595,11 @@ static xmlSAXHandler glade_options_parser = {
 
 
 
-void
+gboolean
 glade_project_load_options (GladeProject *project)
 {
   gchar *filename, *base;
+  gboolean retval = FALSE;
 
   /* Check if the options file exists. If it doesn't we use defaults for
      everything. */
@@ -1607,6 +1617,10 @@ glade_project_load_options (GladeProject *project)
 	{
 	  g_warning("document not well formed!");
 	}
+      else
+	{
+	  retval = TRUE;
+	}
     }
 
   /* Check that the directory options are set to defaults, but only if we
@@ -1625,6 +1639,8 @@ glade_project_load_options (GladeProject *project)
 
   g_free (filename);
   g_free (base);
+
+  return retval;
 }
 
 
