@@ -204,7 +204,7 @@ static GnomeUIInfo FileMenu[] =
     N_("Output the project source code"),
     glade_project_window_write_source, NULL, NULL,
     GNOME_APP_PIXMAP_STOCK, GTK_STOCK_CONVERT,
-    'W', GDK_CONTROL_MASK, NULL
+    'B', GDK_CONTROL_MASK, NULL
   },
   {
     GNOME_APP_UI_ITEM, N_("Op_tions..."),
@@ -655,7 +655,7 @@ glade_project_window_new (void)
 		      GTK_SIGNAL_FUNC (glade_project_window_write_source),
 		      NULL);
   gtk_widget_add_accelerator (menuitem, "activate", accel_group,
-			      'W', GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
+			      'B', GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
   gtk_container_add (GTK_CONTAINER (menu), menuitem);
   gtk_tooltips_set_tip (tooltips, menuitem,
 			_("Output the project source code"), NULL);
@@ -1155,6 +1155,10 @@ glade_project_window_open_project (GladeProjectWindow *project_window,
   GladeProject *project;
   gboolean status;
 
+  /* Clear the project view. Otherwise we may show an invalid project for
+     a while. */
+  glade_project_view_set_project (GLADE_PROJECT_VIEW (project_window->project_view), NULL);
+
   if (filename)
     {
       g_free (project_window->current_directory);
@@ -1888,87 +1892,97 @@ glade_project_window_about (GtkWidget *widget,
   /* VERSION comes from configure.in - the only place it should be defined */
 
 #ifdef USE_GNOME
-  const gchar *author[] = { "Damon Chaplin <damon@gnome.org>",
-			    "Martijn van Beers <martijn@earthling.net>",
-			    "Jacob Berkman <jacob@ximian.com>",
-			    NULL };
-  const gchar *documenter[] = { NULL };
-  GtkWidget *about, *transient_parent;
-  GdkPixbuf *pixbuf = NULL;
-  char *filename;
+  static GtkWidget *about = NULL;
 
-  filename = gnome_program_locate_file (gnome_program_get (),
-					GNOME_FILE_DOMAIN_APP_PIXMAP,
-					"glade-2.png", /* "glade-2/glade_logo.png", */
-					TRUE, NULL);
-  if (filename)
-	  pixbuf = gdk_pixbuf_new_from_file (filename, NULL);
+  if (about == NULL )
+    {
+      const gchar *author[] = { "Damon Chaplin <damon@gnome.org>",
+				"Martijn van Beers <martijn@earthling.net>",
+				"Jacob Berkman <jacob@ximian.com>",
+				NULL };
+      const gchar *documenter[] = { NULL };
+      GtkWidget *transient_parent;
+      GdkPixbuf *pixbuf = NULL;
+      char *filename;
 
-  about = gnome_about_new (_("Glade"),
-			   VERSION,
-			   _("(C) 1998-2002 Damon Chaplin"),
-			   _("Glade is a User Interface Builder for GTK+ and GNOME."),
-			   author, documenter, NULL, pixbuf);
+      filename = gnome_program_locate_file (gnome_program_get (),
+					    GNOME_FILE_DOMAIN_APP_PIXMAP,
+					    "glade-2.png", /* "glade-2/glade_logo.png", */
+					    TRUE, NULL);
+      if (filename)
+	pixbuf = gdk_pixbuf_new_from_file (filename, NULL);
 
-  if (pixbuf)
-	  gdk_pixbuf_unref (pixbuf);
+      about = gnome_about_new (_("Glade"),
+			       VERSION,
+			       _("(C) 1998-2002 Damon Chaplin"),
+			       _("Glade is a User Interface Builder for GTK+ and GNOME."),
+			       author, documenter, NULL, pixbuf);
+      if (pixbuf)
+	gdk_pixbuf_unref (pixbuf);
 			   
-  gtk_window_set_wmclass (GTK_WINDOW (about), "about", "Glade");
-  transient_parent = glade_util_get_toplevel (widget);
-  if (GTK_IS_WINDOW (transient_parent))
-    gtk_window_set_transient_for (GTK_WINDOW (about),
-				  GTK_WINDOW (transient_parent));
+      /* set the widget pointer to NULL when the widget is destroyed */
+      g_signal_connect (G_OBJECT (about), "destroy",
+			G_CALLBACK (gtk_widget_destroyed),
+			&about);
+      gtk_window_set_wmclass (GTK_WINDOW (about), "about", "Glade");
+      transient_parent = glade_util_get_toplevel (widget);
+      if (GTK_IS_WINDOW (transient_parent))
+	gtk_window_set_transient_for (GTK_WINDOW (about),
+				      GTK_WINDOW (transient_parent));
 
-#ifdef FIXME
-  hbox = gtk_hbox_new (TRUE, 0);
-  href = gnome_href_new ("http://glade.gnome.org/",
-			 _("Glade Home Page"));
-  gtk_box_pack_start (GTK_BOX (hbox), href, FALSE, FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (about)->vbox),
-		      hbox, TRUE, FALSE, 0);
-  gtk_widget_show_all (hbox);
-#endif
-
-  gtk_widget_show (about);
+      gtk_widget_show_all (GTK_WIDGET (about));
+    }
+  gtk_window_present (GTK_WINDOW (about));
 
 #else
-  GtkWidget *about, *vbox, *image, *label;
-  GtkWindow *transient_parent;
-  char *filename, *text;
+  static  GtkWidget *about = NULL;
 
-  transient_parent = GTK_WINDOW (glade_util_get_toplevel (widget));
-  about = gtk_dialog_new_with_buttons (_("About Glade"), transient_parent,
-				       0, GTK_STOCK_OK, GTK_RESPONSE_OK, NULL);
-  gtk_window_set_resizable (GTK_WINDOW (about), FALSE);
-  g_signal_connect (G_OBJECT (about), "response",
-		    G_CALLBACK (gtk_widget_destroy), NULL);
-  gtk_window_set_wmclass (GTK_WINDOW (about), "about", "Glade");
+  if (about == NULL )
+    {
+      GtkWidget *vbox, *image, *label;
+      GtkWindow *transient_parent;
+      char *filename, *text;
 
-  vbox = gtk_vbox_new (FALSE, 0);
-  gtk_container_set_border_width (GTK_CONTAINER (vbox), 8);
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (about)->vbox), vbox, TRUE, TRUE, 0);
-  gtk_widget_show (vbox);
+      transient_parent = GTK_WINDOW (glade_util_get_toplevel (widget));
+      about = gtk_dialog_new_with_buttons (_("About Glade"), 
+					   transient_parent,
+					   0, 
+					   GTK_STOCK_OK, 
+					   GTK_RESPONSE_OK, 
+					   NULL);
+      gtk_window_set_resizable (GTK_WINDOW (about), FALSE);
+      g_signal_connect (G_OBJECT (about), "response",
+			G_CALLBACK (gtk_widget_destroy), NULL);
+      /* set the widget pointer to NULL when the widget is destroyed */
+      g_signal_connect (G_OBJECT (about), "destroy",
+			G_CALLBACK (gtk_widget_destroyed),
+			&about);
+      gtk_window_set_wmclass (GTK_WINDOW (about), "about", "Glade");
 
-  filename = g_strdup_printf ("%s/pixmaps/glade-2.png", GLADE_DATADIR);
-  image = gtk_image_new_from_file (filename);
-  g_free (filename);
-  gtk_widget_show (image);
-  gtk_box_pack_start (GTK_BOX (vbox), image, TRUE, TRUE, 8);
+      vbox = gtk_vbox_new (FALSE, 0);
+      gtk_container_set_border_width (GTK_CONTAINER (vbox), 8);
+      gtk_box_pack_start (GTK_BOX (GTK_DIALOG (about)->vbox), 
+			  vbox, TRUE, TRUE, 0);
 
-  text = g_strdup_printf ("<span size=\"xx-large\" weight=\"bold\">Glade "
+      filename = g_strdup_printf ("%s/pixmaps/glade-2.png", GLADE_DATADIR);
+      image = gtk_image_new_from_file (filename);
+      g_free (filename);
+      gtk_box_pack_start (GTK_BOX (vbox), image, TRUE, TRUE, 8);
+
+      text = g_strdup_printf ("<span size=\"xx-large\" weight=\"bold\">Glade "
 			  VERSION "</span>\n\n"
 			 "%s\n\n"
 			  "<span size=\"small\">%s</span>",
 			  _("Glade is a User Interface Builder for GTK+ and GNOME."),
 			  _("(C) 1998-2002 Damon Chaplin"));
 
-  label = gtk_label_new (text);
-  gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-  gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_CENTER);
-  gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, TRUE, 0);
-  gtk_widget_show (label);
-
-  gtk_widget_show (about);
+      label = gtk_label_new (text);
+      gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+      gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_CENTER);
+      gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, TRUE, 0);
+      gtk_widget_show_all (GTK_WIDGET (about));
+    }
+  gtk_window_present (GTK_WINDOW (about));
 #endif
 }
 
