@@ -23,7 +23,9 @@
 #include <string.h>
 #include <sys/types.h>
 #include <sys/stat.h>
+#ifndef _WIN32
 #include <unistd.h>
+#endif
 
 #include <gtk/gtkmain.h>
 #include <gtk/gtkrc.h>
@@ -114,13 +116,20 @@ main (int argc, char *argv[])
   home_dir = NULL;
   rc_path = NULL;
 
+  if (gtk_major_version > 2
+      || (gtk_major_version == 2 && gtk_minor_version > 2))
+    {
+      fprintf (stderr, "This version of Glade requires GTK+ 2.0.x or 2.2.x (found GTK+ %i.%i.%i)\n", gtk_major_version, gtk_minor_version, gtk_micro_version);
+      exit (1);
+    }
+
   /* We need to ensure that gail is loaded, so that we can query accessibility
      info. I can't see a GTK+ function to do that. For now we just add the
      modules we need to the GTK_MODULES environment variable. It doesn't
      matter if modules appear twice. */
   modules = (char*) g_getenv ("GTK_MODULES");
 #ifdef USE_GNOME
-  modules_needed = "gail"; /* FIXME: Add gail-gnome when it is ready. */
+  modules_needed = "gail" G_SEARCHPATH_SEPARATOR_S "gail-gnome";
 #else
   modules_needed = "gail";
 #endif
@@ -162,9 +171,12 @@ main (int argc, char *argv[])
 
   /* For GTK 1.2, default GTK rc files are parsed automatically. */
   home_dir = (gchar*) g_get_home_dir ();
-  rc_path = g_strdup_printf ("%s/.gladerc", home_dir);
-  gtk_rc_add_default_file (rc_path);
-  g_free (rc_path);
+  if (home_dir)
+    {
+      rc_path = g_strdup_printf ("%s/.gladerc", home_dir);
+      gtk_rc_add_default_file (rc_path);
+      g_free (rc_path);
+    }
   gtk_init (&argc, &argv);
 #endif
 
@@ -416,7 +428,7 @@ static void
 usage (void)
 {
   fprintf (stderr, "Usage: glade [-w|--write-source] [<filename>]\n");
-  exit (0);
+  exit (1);
 }
 
 
