@@ -21,14 +21,10 @@
 #include <string.h>
 #include <sys/types.h>
 #include <sys/stat.h>
-#ifdef _WIN32
-#include <ctype.h>
-#include <direct.h>
-#include <dirent.h>
-#else
+#ifndef _WIN32
 #include <unistd.h>
-#include <dirent.h>
 #endif
+#include <dirent.h>
 #include <errno.h>
 
 #include <gtk/gtk.h>
@@ -1657,17 +1653,26 @@ glade_util_get_next_free_project_directory (gchar **project_directory_return,
 {
   GladeError *error = NULL;
   gchar *projects_dir, *project_string, *subdir;
+  const gchar *home_dir;
   DIR *directory;
   struct dirent *entry;
   gint project_num, max_project_num, project_string_len;
   gint num_matched, chars_matched;
 
+  home_dir = g_get_home_dir ();
+  if (home_dir)
+    {
+      projects_dir = glade_util_make_absolute_path (home_dir, _("Projects"));
+    }
+  else
+    {
 #ifdef _WIN32
-  projects_dir = "C:\\Projects";
+      projects_dir = g_strdup ("C:\\Projects");
 #else
-  projects_dir = glade_util_make_absolute_path (g_get_home_dir (),
-						_("Projects"));
+      /* Just use the root directory. Though it probably won't be writable. */
+      projects_dir = g_strdup (G_DIR_SEPARATOR_S);
 #endif
+    }
 
   /* Step through the 'Projects' directory, if it exists, to find
      subdirectories named 'projectXX', and get the highest number used so
@@ -2034,7 +2039,7 @@ guint
 glade_util_flags_from_string (GType type, const char *string)
 {
     GFlagsClass *fclass;
-    gchar *endptr;
+    gchar *endptr, *prevptr;
     guint i, j, ret = 0;
     char *flagstr;
 
@@ -2054,21 +2059,47 @@ glade_util_flags_from_string (GType type, const char *string)
 	if (eos || flagstr [i] == '|') {
 	    GFlagsValue *fv;
 	    const char  *flag;
+	    gunichar ch;
 
 	    flag = &flagstr [j];
+            endptr = &flagstr [i];
 
 	    if (!eos) {
 		flagstr [i++] = '\0';
 		j = i;
 	    }
 
-	    fv = g_flags_get_value_by_name (fclass, flag);
+            /* trim spaces */
+	    for (;;)
+	      {
+		ch = g_utf8_get_char (flag);
+		if (!g_unichar_isspace (ch))
+		  break;
+		flag = g_utf8_next_char (flag);
+	      }
 
-	    if (!fv)
-		fv = g_flags_get_value_by_nick (fclass, flag);
+	    while (endptr > flag)
+	      {
+		prevptr = g_utf8_prev_char (endptr);
+		ch = g_utf8_get_char (prevptr);
+		if (!g_unichar_isspace (ch))
+		  break;
+		endptr = prevptr;
+	      }
 
-	    if (fv)
-		ret |= fv->value;
+	    if (endptr > flag)
+	      {
+		*endptr = '\0';
+		fv = g_flags_get_value_by_name (fclass, flag);
+
+		if (!fv)
+		  fv = g_flags_get_value_by_nick (fclass, flag);
+
+		if (fv)
+		  ret |= fv->value;
+		else
+		  g_warning ("Unknown flag: '%s'", flag);
+	      }
 
 	    if (eos)
 		break;
